@@ -46,14 +46,20 @@ formatting = {
             'detailedWhereAmI' : '[]'
             },
         pyatspi.ROLE_COMBO_BOX: {
-            'focused': 'name + availability',
-            'unfocused': 'labelAndName + roleName + availability'
+            'focused': 'name + positionInList + availability',
+            'unfocused': 'labelAndName + roleName + positionInList + availability'
+            },
+        pyatspi.ROLE_LABEL: {
+            'focused': 'expandableState + availability',
+            'unfocused': 'name + allTextSelection + expandableState + availability + positionInList',
+            'basicWhereAmI': 'roleName + name + positionInList + expandableState + (nodeLevel or nestingLevel)'
             },
         pyatspi.ROLE_PUSH_BUTTON: {
             'unfocused': 'labelAndName + roleName + toggleState + availability',
             'focused': 'labelAndName + toggleState'
             },
         pyatspi.ROLE_TOGGLE_BUTTON: {
+            'unfocused': 'labelAndName + toggleState',
             'focused': 'labelAndName + toggleState'
             },
         pyatspi.ROLE_TABLE_CELL: {
@@ -70,6 +76,10 @@ formatting = {
             },
     },
     'braille': {
+        pyatspi.ROLE_LABEL: {
+            'unfocused': '[Text(obj,asString((label or name)))]',
+            'focused': '[Text(obj,asString((label or name)))]'
+            },
         pyatspi.ROLE_LIST: {
             'unfocused': '[Component(obj,\
                                      asString(labelOrName + roleName + required))]'
@@ -83,7 +93,6 @@ formatting = {
 }
 
 if orca.settings.useExperimentalSpeechProsody:
-    print "Adding pauses to soffice speech formatting strings."
     formatting['speech']['ROLE_SPREADSHEET_CELL']['basicWhereAmI'] = \
         'roleName + pause + column + pause + columnHeader + pause + row + pause + rowHeader + pause + (textContent or spreadSheetCell) + pause + anyTextSelection + pause'
     formatting['speech'][pyatspi.ROLE_TABLE_CELL]['focused'] = \
